# ppsd
This is test repo related to debug the issue 2417


## Resources

* PPSD documentation: Tutorials, Example
* [ppsd-vmd plugin](https://github.com/dsp-testing/ppsd-vmd): VMD plugin to support **PPSD** files.
